You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by mi...@apache.org on 2014/11/26 01:11:06 UTC

svn commit: r1641731 - /db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/store/ClobReclamationTest.java

Author: mikem
Date: Wed Nov 26 00:11:05 2014
New Revision: 1641731

URL: http://svn.apache.org/r1641731
Log:
DERBY-4057 Space is not reclaimed if transaction is rolled back

more tweaking to get tests to run successfully across all platforms.  


Modified:
    db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/store/ClobReclamationTest.java

Modified: db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/store/ClobReclamationTest.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/store/ClobReclamationTest.java?rev=1641731&r1=1641730&r2=1641731&view=diff
==============================================================================
--- db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/store/ClobReclamationTest.java (original)
+++ db/derby/code/trunk/java/testing/org/apache/derbyTesting/functionTests/tests/store/ClobReclamationTest.java Wed Nov 26 00:11:05 2014
@@ -314,11 +314,11 @@ public class ClobReclamationTest extends
         // issue with test and maybe a sleep of some sort is necessary after
         // the rollback.  
 
         // declaring correct run if only max if free pages from 10 pages worth
         // of free space remains.
         // ((clob length / page size ) * 5) + 
         //     1 page for int divide round off - 1 for the head page.
-        checkNumFreePagesMax("CLOBTAB3", ((clob_length / 32000) * 10) + 1 - 1);
+        checkNumFreePagesMax("CLOBTAB3", ((clob_length / 32000) * 20) + 1 - 1);
         commit();
 
         // running inplace compress should reclaim all the remaining aborted
@@ -314,11 +314,11 @@ public class ClobReclamationTest extends
         // the rollback.  
 
-        // declaring correct run if only max if free pages from 10 pages worth
+        // declaring correct run if only max of free pages from 20 rows worth
         // of free space remains.
@@ -314,11 +314,11 @@ public class ClobReclamationTest extends
         // of free space remains.
-        // ((clob length / page size ) * 5) + 
+        // ((clob length / page size ) * 20) + 
         //     1 page for int divide round off - 1 for the head page.